@@ -1,4 +1,5 @@
 from .bedwars import Bedwars
+from .skywars import Skywars
 import datetime
 from .. import utils
 
@@ -47,6 +48,7 @@ class HypixelPlayer:
         self.logins = LoginTimes(data)
         self.social_media = SocialMedia(data)
         self.bedwars = Bedwars(data)
+        self.skywars = Skywars(data)
 
 
 class LoginTimes:
