@@ -20,6 +20,9 @@ class Skywars:
             data.get("player", {}).get("stats", {}).get("SkyWars", {}).get("losses", 0)
         )
 
+    def __str__(self):
+        return self.name
+
 
 class Prestige:
     def __init__(self, data):
